Module api

Module api 

Structs

ABNFGrammar
There is no detailed description.
ClassItem
An item of the class.
CreateCustomClassRequest
Message sent by the client for the CreateCustomClass method.
CreatePhraseSetRequest
Message sent by the client for the CreatePhraseSet method.
CustomClass
A set of words or phrases that represents a common concept likely to appear in your audio, for example a list of passenger ship names. CustomClass items can be substituted into placeholders that you set in PhraseSet phrases.
Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
Entry
A single replacement configuration.
ListCustomClassesResponse
Message returned to the client by the ListCustomClasses method.
ListOperationsResponse
The response message for Operations.ListOperations.
ListPhraseSetResponse
Message returned to the client by the ListPhraseSet method.
LongRunningRecognizeRequest
The top-level message sent by the client for the LongRunningRecognize method.
Operation
This resource represents a long-running operation that is the result of a network API call.
OperationGetCall
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
OperationListCall
Lists operations that match the specified filter in the request. If the server doesn’t support this method, it returns UNIMPLEMENTED.
OperationMethods
A builder providing access to all methods supported on operation resources. It is not used directly, but through the Speech hub.
Phrase
A phrases containing words and phrase “hints” so that the speech recognition is more likely to recognize them. This can be used to improve the accuracy for specific words and phrases, for example, if specific commands are typically spoken by the user. This can also be used to add additional words to the vocabulary of the recognizer. See usage limits. List items can also include pre-built or custom classes containing groups of words that represent common concepts that occur in natural language. For example, rather than providing a phrase hint for every month of the year (e.g. “i was born in january”, “i was born in febuary”, …), use the pre-built $MONTH class improves the likelihood of correctly transcribing audio that includes months (e.g. “i was born in $month”). To refer to pre-built classes, use the class’ symbol prepended with $ e.g. $MONTH. To refer to custom classes that were defined inline in the request, set the class’s custom_class_id to a string unique to all class resources and inline classes. Then use the class’ id wrapped in ${...} e.g. “${my-months}”. To refer to custom classes resources, use the class’ id wrapped in ${} (e.g. ${my-months}). Speech-to-Text supports three locations: global, us (US North America), and eu (Europe). If you are calling the speech.googleapis.com endpoint, use the global location. To specify a region, use a regional endpoint with matching us or eu location value.
PhraseSet
Provides “hints” to the speech recognizer to favor specific words and phrases in the results.
ProjectLocationCustomClassCreateCall
Create a custom class.
ProjectLocationCustomClassDeleteCall
Delete a custom class.
ProjectLocationCustomClassGetCall
Get a custom class.
ProjectLocationCustomClassListCall
List custom classes.
ProjectLocationCustomClassPatchCall
Update a custom class.
ProjectLocationPhraseSetCreateCall
Create a set of phrase hints. Each item in the set can be a single word or a multi-word phrase. The items in the PhraseSet are favored by the recognition model when you send a call that includes the PhraseSet.
ProjectLocationPhraseSetDeleteCall
Delete a phrase set.
ProjectLocationPhraseSetGetCall
Get a phrase set.
ProjectLocationPhraseSetListCall
List phrase sets.
ProjectLocationPhraseSetPatchCall
Update a phrase set.
ProjectMethods
A builder providing access to all methods supported on project resources. It is not used directly, but through the Speech hub.
RecognitionAudio
Contains audio data in the encoding specified in the RecognitionConfig. Either content or uri must be supplied. Supplying both or neither returns google.rpc.Code.INVALID_ARGUMENT. See content limits.
RecognitionConfig
Provides information to the recognizer that specifies how to process the request.
RecognitionMetadata
Description of audio data to be recognized.
RecognizeRequest
The top-level message sent by the client for the Recognize method.
RecognizeResponse
The only message returned to the client by the Recognize method. It contains the result as zero or more sequential SpeechRecognitionResult messages.
SpeakerDiarizationConfig
Config to enable speaker diarization.
Speech
Central instance to access all Speech related resource activities
SpeechAdaptation
Speech adaptation configuration.
SpeechAdaptationInfo
Information on speech adaptation use in results
SpeechContext
Provides “hints” to the speech recognizer to favor specific words and phrases in the results.
SpeechLongrunningrecognizeCall
Performs asynchronous speech recognition: receive results via the google.longrunning.Operations interface. Returns either an Operation.error or an Operation.response which contains a LongRunningRecognizeResponse message. For more information on asynchronous speech recognition, see the how-to.
SpeechMethods
A builder providing access to all methods supported on speech resources. It is not used directly, but through the Speech hub.
SpeechRecognitionAlternative
Alternative hypotheses (a.k.a. n-best list).
SpeechRecognitionResult
A speech recognition result corresponding to a portion of the audio.
SpeechRecognizeCall
Performs synchronous speech recognition: receive results after all audio has been sent and processed.
Status
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.
TranscriptNormalization
Transcription normalization configuration. Use transcription normalization to automatically replace parts of the transcript with phrases of your choosing. For StreamingRecognize, this normalization only applies to stable partial transcripts (stability > 0.8) and final transcripts.
TranscriptOutputConfig
Specifies an optional destination for the recognition results.
WordInfo
Word-specific information for recognized words.

Enums

Scope
Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.