pub struct ABNFGrammar {
pub abnf_strings: Option<Vec<String>>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
abnf_strings: Option<Vec<String>>All declarations and rules of an ABNF grammar broken up into multiple strings that will end up concatenated.