Phrase

Struct Phrase 

pub struct Phrase {
    pub boost: Option<f32>,
    pub value: Option<String>,
}
A phrases containing words and phrase “hints” so that the speech recognition is more likely to recognize them. This can be used to improve the accuracy for specific words and phrases, for example, if specific commands are typically spoken by the user. This can also be used to add additional words to the vocabulary of the recognizer. See usage limits. List items can also include pre-built or custom classes containing groups of words that represent common concepts that occur in natural language. For example, rather than providing a phrase hint for every month of the year (e.g. “i was born in january”, “i was born in febuary”, …), use the pre-built $MONTH class improves the likelihood of correctly transcribing audio that includes months (e.g. “i was born in $month”). To refer to pre-built classes, use the class’ symbol prepended with $ e.g. $MONTH. To refer to custom classes that were defined inline in the request, set the class’s custom_class_id to a string unique to all class resources and inline classes. Then use the class’ id wrapped in ${...} e.g. “${my-months}”. To refer to custom classes resources, use the class’ id wrapped in ${} (e.g. ${my-months}). Speech-to-Text supports three locations: global, us (US North America), and eu (Europe). If you are calling the speech.googleapis.com endpoint, use the global location. To specify a region, use a regional endpoint with matching us or eu location value.

This type is not used in any activity, and only used as part of another schema.

Fields

boost: Option<f32>

Hint Boost. Overrides the boost set at the phrase set level. Positive value will increase the probability that a specific phrase will be recognized over other similar sounding phrases. The higher the boost, the higher the chance of false positive recognition as well. Negative boost will simply be ignored. Though boost can accept a wide range of positive values, most use cases are best served with values between 0 and 20. We recommend using a binary search approach to finding the optimal value for your use case as well as adding phrases both with and without boost to your requests.

value: Option<String>

The phrase itself.