pub struct RecognizeResponse {
pub request_id: Option<i64>,
pub results: Option<Vec<SpeechRecognitionResult>>,
pub speech_adaptation_info: Option<SpeechAdaptationInfo>,
pub total_billed_time: Option<Duration>,
pub using_legacy_models: Option<bool>,
}Expand description
The only message returned to the client by the Recognize method. It contains the result as zero or more sequential SpeechRecognitionResult messages.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- recognize speech (response)
Fields
request_id: Option<i64>The ID associated with the request. This is a unique ID specific only to the given request.
results: Option<Vec<SpeechRecognitionResult>>Sequential list of transcription results corresponding to sequential portions of audio.
speech_adaptation_info: Option<SpeechAdaptationInfo>Provides information on adaptation behavior in response
total_billed_time: Option<Duration>When available, billed audio seconds for the corresponding request.
using_legacy_models: Option<bool>Whether request used legacy asr models (was not automatically migrated to use conformer models).