pub struct SpeechRecognitionResult {
pub alternatives: Option<Vec<SpeechRecognitionAlternative>>,
pub channel_tag: Option<i32>,
pub language_code: Option<String>,
pub result_end_time: Option<Duration>,
}Expand description
A speech recognition result corresponding to a portion of the audio.
This type is not used in any activity, and only used as part of another schema.
Fields
alternatives: Option<Vec<SpeechRecognitionAlternative>>May contain one or more recognition hypotheses (up to the maximum specified in max_alternatives). These alternatives are ordered in terms of accuracy, with the top (first) alternative being the most probable, as ranked by the recognizer.
channel_tag: Option<i32>For multi-channel audio, this is the channel number corresponding to the recognized result for the audio from that channel. For audio_channel_count = N, its output values can range from ‘1’ to ‘N’.
language_code: Option<String>Output only. The BCP-47 language tag of the language in this result. This language code was detected to have the most likelihood of being spoken in the audio.
result_end_time: Option<Duration>Time offset of the end of this result relative to the beginning of the audio.