TranscriptNormalization

Struct TranscriptNormalization 

pub struct TranscriptNormalization {
    pub entries: Option<Vec<Entry>>,
}
Transcription normalization configuration. Use transcription normalization to automatically replace parts of the transcript with phrases of your choosing. For StreamingRecognize, this normalization only applies to stable partial transcripts (stability > 0.8) and final transcripts.

This type is not used in any activity, and only used as part of another schema.

Fields

entries: Option<Vec<Entry>>

A list of replacement entries. We will perform replacement with one entry at a time. For example, the second entry in [“cat” => “dog”, “mountain cat” => “mountain dog”] will never be applied because we will always process the first entry before it. At most 100 entries.