[−][src]Struct google_speech1::RecognitionAudio
Contains audio data in the encoding specified in the RecognitionConfig.
Either content or uri must be supplied. Supplying both or neither
returns google.rpc.Code.INVALID_ARGUMENT. See
content limits.
This type is not used in any activity, and only used as part of another schema.
Fields
content: Option<String>The audio data bytes encoded as specified in
RecognitionConfig. Note: as with all bytes fields, proto buffers use a
pure binary representation, whereas JSON representations use base64.
uri: Option<String>URI that points to a file that contains audio data bytes as specified in
RecognitionConfig. The file must not be compressed (for example, gzip).
Currently, only Google Cloud Storage URIs are
supported, which must be specified in the following format:
gs://bucket_name/object_name (other URI formats return
google.rpc.Code.INVALID_ARGUMENT). For more information, see
Request URIs.