[][src]Struct google_speech1::RecognizeRequest

pub struct RecognizeRequest {
    pub audio: Option<RecognitionAudio>,
    pub config: Option<RecognitionConfig>,
}

The top-level message sent by the client for the Recognize method.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

audio: Option<RecognitionAudio>

Required. The audio data to be recognized.

config: Option<RecognitionConfig>

Required. Provides information to the recognizer that specifies how to process the request.