pub struct RecognitionMetadata {
pub audio_topic: Option<String>,
pub industry_naics_code_of_audio: Option<u32>,
pub interaction_type: Option<String>,
pub microphone_distance: Option<String>,
pub original_media_type: Option<String>,
pub original_mime_type: Option<String>,
pub recording_device_name: Option<String>,
pub recording_device_type: Option<String>,
}Expand description
Description of audio data to be recognized.
This type is not used in any activity, and only used as part of another schema.
Fields
audio_topic: Option<String>Description of the content. Eg. “Recordings of federal supreme court hearings from 2012”.
industry_naics_code_of_audio: Option<u32>The industry vertical to which this speech recognition request most closely applies. This is most indicative of the topics contained in the audio. Use the 6-digit NAICS code to identify the industry vertical - see https://www.naics.com/search/.
interaction_type: Option<String>The use case most closely describing the audio content to be recognized.
microphone_distance: Option<String>The audio type that most closely describes the audio being recognized.
original_media_type: Option<String>The original media the speech was recorded on.
original_mime_type: Option<String>Mime type of the original audio file. For example audio/m4a, audio/x-alaw-basic, audio/mp3, audio/3gpp. A list of possible audio mime types is maintained at http://www.iana.org/assignments/media-types/media-types.xhtml#audio
recording_device_name: Option<String>The device used to make the recording. Examples ‘Nexus 5X’ or ‘Polycom SoundStation IP 6000’ or ‘POTS’ or ‘VoIP’ or ‘Cardioid Microphone’.
recording_device_type: Option<String>The type of device the speech was recorded with.