pub struct SpeakerDiarizationConfig {
pub enable_speaker_diarization: Option<bool>,
pub max_speaker_count: Option<i32>,
pub min_speaker_count: Option<i32>,
pub speaker_tag: Option<i32>,
}Expand description
Config to enable speaker diarization.
This type is not used in any activity, and only used as part of another schema.
Fields
enable_speaker_diarization: Option<bool>If ‘true’, enables speaker detection for each recognized word in the top alternative of the recognition result using a speaker_label provided in the WordInfo.
max_speaker_count: Option<i32>Maximum number of speakers in the conversation. This range gives you more flexibility by allowing the system to automatically determine the correct number of speakers. If not set, the default value is 6.
min_speaker_count: Option<i32>Minimum number of speakers in the conversation. This range gives you more flexibility by allowing the system to automatically determine the correct number of speakers. If not set, the default value is 2.
speaker_tag: Option<i32>Output only. Unused.