pub struct SpeechAdaptation {
pub abnf_grammar: Option<ABNFGrammar>,
pub custom_classes: Option<Vec<CustomClass>>,
pub phrase_set_references: Option<Vec<String>>,
pub phrase_sets: Option<Vec<PhraseSet>>,
}Expand description
Speech adaptation configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
abnf_grammar: Option<ABNFGrammar>Augmented Backus-Naur form (ABNF) is a standardized grammar notation comprised by a set of derivation rules. See specifications: https://www.w3.org/TR/speech-grammar
custom_classes: Option<Vec<CustomClass>>A collection of custom classes. To specify the classes inline, leave the class’ name blank and fill in the rest of its fields, giving it a unique custom_class_id. Refer to the inline defined class in phrase hints by its custom_class_id.
phrase_set_references: Option<Vec<String>>A collection of phrase set resource names to use.
phrase_sets: Option<Vec<PhraseSet>>A collection of phrase sets. To specify the hints inline, leave the phrase set’s name blank and fill in the rest of its fields. Any phrase set can use any custom class.